# Project Documentation

Documentation for **civic-exchange-protocol**.

Use the navigation menu to explore available modules and APIs.

- The **API Reference** section includes autogenerated docs from the source code.
- This home page will always be served at `/`.

To learn more, visit the [GitHub repository](https://github.com/civic-interconnect/civic-exchange-protocol).
